==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiablePrintServiceAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class 9ba91c1fa04705e2 javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$method$_init$8dd1ca2c0646d12a(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiablePrintServiceAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class 9ba91c1fa04705e2 javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$method$_init$8dd1ca2c0646d12a(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintServiceAttributeSet_H_ */
